==> arrow-docs-0.8.1-sources.jar: arrow/optics/HealthPack$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`HealthPack`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`HealthPack`, `kotlin`.`Int`> inline get()= arrow.optics.Iso(
  get = { healthPack: `arrow`.`optics`.`HealthPack` -> healthPack.amountLeft },
  reverseGet = { `arrow`.`optics`.`HealthPack`(it) }
)

inline val `arrow`.`optics`.`HealthPack`.Companion.amountLeft: arrow.optics.Lens<`arrow`.`optics`.`HealthPack`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { healthPack: `arrow`.`optics`.`HealthPack` -> healthPack.`amountLeft` },
  set = { value: `kotlin`.`Int` ->
    { healthPack: `arrow`.`optics`.`HealthPack` ->
      healthPack.copy(`amountLeft` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft

==> arrow-docs-0.10.3-sources.jar: arrow/optics/HealthPack$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`HealthPack`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`HealthPack`, `kotlin`.`Int`> inline get()= arrow.optics.Iso(
  get = { healthPack: `arrow`.`optics`.`HealthPack` -> healthPack.amountLeft },
  reverseGet = { `arrow`.`optics`.`HealthPack`(it) }
)

inline val `arrow`.`optics`.`HealthPack`.Companion.amountLeft: arrow.optics.Lens<`arrow`.`optics`.`HealthPack`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { healthPack: `arrow`.`optics`.`HealthPack` -> healthPack.`amountLeft` },
  set = { healthPack: `arrow`.`optics`.`HealthPack`, value: `kotlin`.`Int` -> healthPack.copy(`amountLeft` = value) }
)



inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`HealthPack`>.amountLeft: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`HealthPack`.amountLeft
